@@ -1,19 +1,19 @@
 """
-Routines for beta expansion(s)
+Inverse temperature (beta) extrapolation (:mod:`~thermoextrap.beta`)
+====================================================================
 """
 
 
 from functools import lru_cache
 from typing import Literal
 
-import sympy as sp
-
 from .core._docstrings import factory_docfiller_shared
 from .core.models import (
     Derivatives,
     ExtrapModel,
     PerturbModel,
     SymDerivBase,
+    SymFuncBase,
     SymSubs,
     get_default_indexed,
     get_default_symbol,
@@ -30,16 +30,16 @@ docfiller_shared = factory_docfiller_shared(names=("default", "beta"))
 ####################
 
 
-class du_func(sp.Function):
+class du_func(SymFuncBase):
     r"""
     Sympy function to evaluate energy fluctuations using central moments.
 
-    :math:`du_func(\beta, n) = \langle (u(\beta) - \langle u(\beta) \rangle)^n \rangle`
+    :math:`\text{du_func}(\beta, n) = \langle (u(\beta) - \langle u(\beta) \rangle)^n \rangle`
 
     Notes
     -----
-    sub in {beta: 'None'} to convert to indexed objects
-    Have to use 'None' instead of None as sympy does some magic to
+    sub in ``{'beta': 'None'}`` to convert to indexed objects
+    Have to use ``'None'`` instead of ``None`` as sympy does some magic to
     the input arguments.
     """
 
@@ -48,7 +48,6 @@ class du_func(sp.Function):
 
     @classmethod
     def deriv_args(cls):
-        """list of arguments to function evaluation"""
         return [cls.du]
 
     def fdiff(self, argindex=1):
@@ -69,11 +68,11 @@ class du_func(sp.Function):
         return out
 
 
-class u_func_central(sp.Function):
-    """
+class u_func_central(SymFuncBase):
+    r"""
     Sympy function to evaluate energy averages using central moments.
 
-    :math:`u_func_central(beta, n) = \\langle u(\beta)^n \rangle`
+    :math:`\text{u_func_central}(beta, n) = \langle u(\beta)^n \rangle`
     """
 
     nargs = 1
@@ -97,11 +96,11 @@ class u_func_central(sp.Function):
         return out
 
 
-class dxdu_func_nobeta(sp.Function):
-    """
+class dxdu_func_nobeta(SymFuncBase):
+    r"""
     Sympy function to evaluate observable energy fluctuations using central moments.
 
-    :math:`dxdu_func_nobeta(\beta, n) = \\langle \\delta x (\\delta u)^n \rangle`
+    :math:`\text{dxdu_func_nobeta}(\beta, n) = \langle \delta x (\delta u)^n \rangle`
 
     for use when x is not a function of beta.
     """
@@ -133,11 +132,11 @@ class dxdu_func_nobeta(sp.Function):
         return out
 
 
-class dxdu_func_beta(sp.Function):
+class dxdu_func_beta(SymFuncBase):
     r"""
     Sympy function to evaluate derivatives of observable fluctuations using central moments.
 
-    :math:`dxdu_func_beta(\beta, n, d) = \langle \delta  x^{(d)}(\beta)(\delta u)^n \rangle`, where :math:`x^{(k)} = d^k x / d\beta^k`.
+    :math:`\text{dxdu_func_beta}(\beta, n, d) = \langle \delta  x^{(d)}(\beta)(\delta u)^n \rangle`, where :math:`x^{(k)} = d^k x / d\beta^k`.
 
     """
 
@@ -169,10 +168,8 @@ class dxdu_func_beta(sp.Function):
         return out
 
 
-class x_func_central_nobeta(sp.Function):
-    r"""
-    Sympy functionn to evaluate derivatives of observable :math:`\langle x \rangle` using central moments.
-    """
+class x_func_central_nobeta(SymFuncBase):
+    r"""Sympy functionn to evaluate derivatives of observable :math:`\langle x \rangle` using central moments."""
 
     nargs = 1
     x1_symbol = get_default_symbol("x1")
@@ -194,10 +191,8 @@ class x_func_central_nobeta(sp.Function):
         return out
 
 
-class x_func_central_beta(sp.Function):
-    """
-    Sympy function to evaluate derivatives of observable :math:`\\langle x(\beta) \rangle` using central moments.
-    """
+class x_func_central_beta(SymFuncBase):
+    r"""Sympy function to evaluate derivatives of observable :math:`\langle x(\beta) \rangle` using central moments."""
 
     nargs = 2
     x1_indexed = get_default_indexed("x1")
@@ -224,10 +219,8 @@ class x_func_central_beta(sp.Function):
 ####################
 # raw moments
 ####################
-class u_func(sp.Function):
-    """
-    Sympy funciton to evaluate derivatives of energy :math:`\\langle u \rangle` using raw moments.
-    """
+class u_func(SymFuncBase):
+    r"""Sympy function to evaluate derivatives of energy :math:`\langle u \rangle` using raw moments."""
 
     nargs = 2
     u = get_default_indexed("u")
@@ -251,11 +244,11 @@ class u_func(sp.Function):
         return out
 
 
-class xu_func(sp.Function):
-    """
-    Sympy function to evaluate derivatives of :math:`\\langle x u^n \rangle`.
+class xu_func(SymFuncBase):
+    r"""
+    Sympy function to evaluate derivatives of :math:`\langle x u^n \rangle`.
 
-    If ``x`` is a funciton of ``beta``, then :math:`xu_func(\beta, n, d) = \\langle x^{(d)} u^n \rangle`.
+    If ``x`` is a function of ``beta``, then :math:`\text{xu_func}(\beta, n, d) = \langle x^{(d)} u^n \rangle`.
     If ``x`` is not a function of ``beta``, drop argument ``d``.
     """
 
@@ -293,18 +286,19 @@ class xu_func(sp.Function):
 
 
 class SymDerivBeta(SymDerivBase):
-    r"""
-    Provide symbolic expressions for :math:`d^n \langle x \rangle /d\beta^n`.
-    """
+    r"""Provide symbolic expressions for :math:`d^n \langle x \rangle /d\beta^n`."""
+
     beta = get_default_symbol("beta")
 
     @classmethod
     @docfiller_shared
-    def x_ave(cls, xalpha=False, central=None, expand=True, post_func=None):
+    def x_ave(
+        cls, xalpha=False, central=None, expand=True, post_func=None
+    ):  # noqa: 417
         r"""
-        General method to find derivatives of :math:`langle x \rangle`
+        General method to find derivatives of :math:`\langle x \rangle`.
 
-        Paremeters
+        Parameters
         ----------
         {xalpha}
         {central}
@@ -331,9 +325,9 @@ class SymDerivBeta(SymDerivBase):
 
     @classmethod
     @docfiller_shared
-    def u_ave(cls, central=None, expand=True, post_func=None):
+    def u_ave(cls, central=None, expand=True, post_func=None):  # noqa: D417
         r"""
-        General constructor for symbolic derivatives of :math:`\langle u \rangle`
+        General constructor for symbolic derivatives of :math:`\langle u \rangle`.
 
         Parameters
         ----------
@@ -354,9 +348,9 @@ class SymDerivBeta(SymDerivBase):
 
     @classmethod
     @docfiller_shared
-    def dun_ave(cls, n, expand=True, post_func=None, central=None):
-        """
-        Constructor for derivatives of :math:`\\langle (\\delta u)^n\rangle`.
+    def dun_ave(cls, n, expand=True, post_func=None, central=None):  # noqa: D417
+        r"""
+        Constructor for derivatives of :math:`\langle (\delta u)^n\rangle`.
 
         Parameters
         ----------
@@ -493,7 +487,7 @@ class SymDerivBeta(SymDerivBase):
         d=None,
     ):
         """
-        create a derivative expressions indexer by name
+        Create a derivative expressions indexer by name.
 
         Parameters
         ----------
@@ -536,7 +530,7 @@ class SymDerivBeta(SymDerivBase):
             kws.update(n=n, xalpha=xalpha, d=d)
 
         elif name == "lnPi_correction":
-            # aleady have central
+            # already have central
             pass
 
         return func(**kws)
@@ -559,7 +553,7 @@ def factory_derivatives(
     expand=True,
 ):
     r"""
-    Factory function to provide derivative function for expansion
+    Factory function to provide derivative function for expansion.
 
     Parameters
     ----------
@@ -570,7 +564,7 @@ def factory_derivatives(
 
     Returns
     -------
-    derivatives : :class:`thermoextrap.Derivatives` instance
+    derivatives : :class:`thermoextrap.models.Derivatives` instance
         Object used to calculate taylor series coefficients
     """
 
@@ -609,7 +603,7 @@ def factory_extrapmodel(
     derivatives_kws=None,
 ):
     """
-    Factory function to create Extrapolation model for beta expansion
+    Factory function to create Extrapolation model for beta expansion.
 
     Parameters
     ----------
@@ -627,17 +621,17 @@ def factory_extrapmodel(
 
     Returns
     -------
-    extrapmodel : :class:`~thermoextrap.ExtrapModel`
+    extrapmodel : :class:`~thermoextrap.models.ExtrapModel`
 
 
     Notes
     -----
     Note that default values for parameters ``order``, ``xalpha``, and ``central``
-    are infered from corresponding attributes of ``data``.
+    are inferred from corresponding attributes of ``data``.
 
     See Also
     --------
-    ~thermoextrap.ExtrapModel
+    ~thermoextrap.models.ExtrapModel
     """
 
     if xalpha is None:
@@ -679,7 +673,7 @@ def factory_extrapmodel(
 @docfiller_shared
 def factory_perturbmodel(beta, uv, xv, alpha_name="beta", **kws):
     """
-    Factory function to create PerturbModel for beta expansion
+    Factory function to create PerturbModel for beta expansion.
 
     Parameters
     ----------
@@ -691,12 +685,12 @@ def factory_perturbmodel(beta, uv, xv, alpha_name="beta", **kws):
 
     Returns
     -------
-    perturbmodel : :class:`thermoextrap.PerturbModel`
+    perturbmodel : :class:`thermoextrap.models.PerturbModel`
 
 
     See Also
     --------
-    ~thermoextrap.PerturbModel
+    ~thermoextrap.models.PerturbModel
     """
     from .core.data import factory_data_values
 
