@@ -1,3 +1,4 @@
+"""Classes/routines to fill common documentation."""
 from __future__ import annotations
 
 import inspect
@@ -128,7 +129,7 @@ def _get_nested_values(d, join_string="\n"):
 
 class AttributeDict(Mapping):
     """
-    Dictionary with recusive attribute like access.
+    Dictionary with recursive attribute like access.
 
     To be used in str.format calls, so can expand on fields like
     `{name.property}` in a nested manner.
@@ -153,6 +154,7 @@ class AttributeDict(Mapping):
     __slots__ = ("_entries", "_recursive", "_allow_missing")
 
     def __init__(self, entries=None, recursive=True, allow_missing=True):
+        """Init."""
         if entries is None:
             entries = {}
         self._entries = entries
@@ -160,7 +162,6 @@ class AttributeDict(Mapping):
         self._allow_missing = allow_missing
 
     def __getitem__(self, key):
-
         if isinstance(key, slice):
             return _get_nested_values(self._getslice(key), join_string="\n")
 
@@ -176,7 +177,6 @@ class AttributeDict(Mapping):
             return self._entries[key]
 
     def _getslice(self, s):
-
         start = s.start
         stop = s.stop
 
@@ -297,7 +297,7 @@ def _build_param_docstring(name, ptype, desc):
     Create multiline documentation of single name, type, desc.
 
     Parameters
-    ==========
+    ----------
     name : str
         Parameter Name
     ptype : str
@@ -338,7 +338,7 @@ def _build_param_docstring(name, ptype, desc):
 
 def _params_to_string(params, key_char="|"):
     """
-    Parse list of Parameters objects to string
+    Parse list of Parameters objects to string.
 
     Examples
     --------
@@ -438,7 +438,6 @@ def parse_docstring(func_or_doc, key_char="|", expand=True):
     parsed = NumpyDocString(doc)._parsed_data
 
     if expand:
-
         parsed = {
             k.replace(" ", "_").lower(): _params_to_string(parsed[k], key_char=key_char)
             for k in [
@@ -460,9 +459,7 @@ def parse_docstring(func_or_doc, key_char="|", expand=True):
 
 
 def dedent_recursive(data):
-    """
-    Dedent nested mapping of strings.
-    """
+    """Dedent nested mapping of strings."""
     out = type(data)()
     for k in data:
         v = data[k]
@@ -477,7 +474,6 @@ def dedent_recursive(data):
 def _recursive_keys(data):
     keys = []
     for k, v in data.items():
-
         if isinstance(v, dict):
             key_list = [f"{k}.{x}" for x in _recursive_keys(v)]
         elif isinstance(v, str):
@@ -492,7 +488,6 @@ def _recursive_keys(data):
 
 class DocFiller:
     """
-
     Parameters
     ----------
     func_or_doc : callable or str
@@ -502,6 +497,7 @@ class DocFiller:
     """
 
     def __init__(self, params=None):
+        """Init."""
         if params is None:
             params = {}
         self.data = params
@@ -524,9 +520,7 @@ class DocFiller:
         return _recursive_keys(self.data)
 
     def assign_combined_key(self, new_key, keys):
-        """
-        combine multiple keys into single key
-        """
+        """Combine multiple keys into single key."""
 
         data = self.data.copy()
 
@@ -574,9 +568,7 @@ class DocFiller:
         return cls(data)
 
     def append(self, *args, **kwargs):
-        """
-        Calls ``concat`` method with ``self`` as first argument.
-        """
+        """Calls ``concat`` method with ``self`` as first argument."""
 
         return type(self).concat(self, *args, **kwargs)
 
@@ -616,7 +608,6 @@ class DocFiller:
             return docfiller(*templates)
 
     def __call__(self, *templates, **params):
-
         if len(params) > 0:
             params = AttributeDict.from_dict({**self.data, **params}, max_level=1)
             return docfiller(*templates, **params)
@@ -708,7 +699,7 @@ class DocFiller:
         key_map=None,
     ):
         """
-        create a Docfiller instance from a function or docstring.
+        Create a Docfiller instance from a function or docstring.
 
         Parameters
         ----------
